pub struct WasmEnv<E: EvmApi> {
pub args: Vec<u8>,
pub outs: Vec<u8>,
pub memory: Option<Memory>,
pub meter: Option<MeterData>,
pub evm_api: E,
pub evm_data: EvmData,
pub evm_return_data_len: u32,
pub compile: CompileConfig,
pub config: Option<StylusConfig>,
/* private fields */
}Expand description
The WASM execution environment.
Contains all state needed during Stylus program execution, including the EVM API bridge, metering state, and I/O buffers.
Fields
args: Vec<u8>The instance’s arguments.
outs: Vec<u8>The instance’s return data.
memory: Option<Memory>WASM linear memory.
meter: Option<MeterData>Ink metering state via WASM globals.
evm_api: EBridge to EVM state (storage, calls, etc.).
evm_data: EvmDataEVM context data (block info, sender, etc.).
evm_return_data_len: u32Cached length of the last call’s return data.
compile: CompileConfigCompile-time configuration.
config: Option<StylusConfig>Runtime configuration (set when running).
Implementations
Sourceimpl<E: EvmApi> WasmEnv<E>
impl<E: EvmApi> WasmEnv<E>
pub fn new( compile: CompileConfig, config: Option<StylusConfig>, evm_api: E, evm_data: EvmData, ) -> Self
Sourcepub fn start<'a>(
env: &'a mut WasmEnvMut<'_, E>,
ink: Ink,
) -> Result<HostioInfo<'a, E>, Escape>
pub fn start<'a>( env: &'a mut WasmEnvMut<'_, E>, ink: Ink, ) -> Result<HostioInfo<'a, E>, Escape>
Create a HostioInfo and charge the standard hostio cost plus ink.
Sourcepub fn program<'a>(
env: &'a mut WasmEnvMut<'_, E>,
) -> Result<HostioInfo<'a, E>, Escape>
pub fn program<'a>( env: &'a mut WasmEnvMut<'_, E>, ) -> Result<HostioInfo<'a, E>, Escape>
Create a HostioInfo for accessing host functionality.
pub fn meter_mut(&mut self) -> &mut MeterData
pub fn meter(&self) -> &MeterData