pub fn account_touch(is_cold: bool, ext_code_cost: u64) -> MultiGas
Dimension split of touching an account in Stylus, matching EIP-2929 account access. ext_code_cost is the extra read charged when the code is loaded.
ext_code_cost