pub fn record_leaf(name: &'static str, args: Bytes, outs: Bytes)Expand description
Convenience wrapper for host functions that want to record the call name with optional args + outs and no ink delta (e.g., leaf host functions that never block or touch state).